==> react-ui-library-0.5.8.tgz: package/src/stories/sidebar-story.js <==
import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Content,
  NavigationBar,
  Sidebar,
  SidebarLink,
  Avatar,
  Box,
  Triangle,
} from '../components'

const AvatarWithTriangle = () => <Box  display='inline-flex' alignItems='center'>
  <Avatar marginLeft={2} marginRight={2} src='' imageSize='small'>Segment Sloth</Avatar>
  <Triangle aim='down'  display='inline-flex' fill='white' />
</Box>


export default function sidebarStory (module) {
  storiesOf('Sidebar', module)
    .add('usage', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Sidebar

The Sidebar component. Composes \`<Pane />\`.
The SidebarLink components. Composes \`<Link />\`.

\`\`\`
<Sidebar>
  <SidebarLink href='#' active>Tracks</SidebarLink>
  <SidebarLink href='#'>Page</SidebarLink>
  <SidebarLink href='#'>Screen</SidebarLink>
  <SidebarLink href='#'>Identify</SidebarLink>
  <SidebarLink href='#'>Group</SidebarLink>
</Sidebar>
\`\`\`

`}
          </Content>
          <Sidebar>
            <SidebarLink href='#' active>Tracks</SidebarLink>
            <SidebarLink href='#'>Page</SidebarLink>
            <SidebarLink href='#'>Screen</SidebarLink>
            <SidebarLink href='#'>Identify</SidebarLink>
            <SidebarLink href='#'>Group</SidebarLink>
          </Sidebar>
          <Content markdown>
{`
prop | type | default | description
-----|------| --------|-------------
\`children\` | node | undefined | contents of Sidebar
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('with Sidebar Links', () => (
      <Sidebar flexAuto>
        <SidebarLink href='#' active>Tracks</SidebarLink>
        <SidebarLink href='#'>Page</SidebarLink>
        <SidebarLink href='#'>Screen</SidebarLink>
        <SidebarLink href='#'>Identify</SidebarLink>
        <SidebarLink href='#'>Group</SidebarLink>
      </Sidebar>
    ))
}

==> react-ui-library-0.9.0.tgz: package/src/stories/sidebar-story.js <==
import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Pane,
  Content,
  NavigationBar,
  Sidebar,
  SidebarLink,
  Avatar,
  Box,
  Triangle,
  theme
} from '../components'
const { minorScale, majorScale } = theme

const AvatarWithTriangle = () => <Box  display='inline-flex' alignItems='center'>
  <Avatar marginLeft={2} marginRight={2} src='' imageSize='small'>Segment Sloth</Avatar>
  <Triangle aim='down'  display='inline-flex' fill='white' />
</Box>


export default function sidebarStory (module) {
  storiesOf('Sidebar', module)
    .add('usage', () => (
      <App>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
{`
# Sidebar

The Sidebar component. Composes \`<Pane />\`.
The SidebarLink components. Composes \`<Link />\`.

\`\`\`
<Sidebar>
  <SidebarLink href='#' active>Tracks</SidebarLink>
  <SidebarLink href='#'>Page</SidebarLink>
  <SidebarLink href='#'>Screen</SidebarLink>
  <SidebarLink href='#'>Identify</SidebarLink>
  <SidebarLink href='#'>Group</SidebarLink>
</Sidebar>
\`\`\`

`}
          </Content>
          <Sidebar>
            <SidebarLink href='#' active>Tracks</SidebarLink>
            <SidebarLink href='#'>Page</SidebarLink>
            <SidebarLink href='#'>Screen</SidebarLink>
            <SidebarLink href='#'>Identify</SidebarLink>
            <SidebarLink href='#'>Group</SidebarLink>
          </Sidebar>
          <Content markdown>
{`
prop | type | default | description
-----|------| --------|-------------
\`children\` | node | undefined | contents of Sidebar
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('with Sidebar Links', () => (
      <Sidebar flexAuto>
        <SidebarLink href='#' active>Tracks</SidebarLink>
        <SidebarLink href='#'>Page</SidebarLink>
        <SidebarLink href='#'>Screen</SidebarLink>
        <SidebarLink href='#'>Identify</SidebarLink>
        <SidebarLink href='#'>Group</SidebarLink>
      </Sidebar>
    ))
}
